@@ -303,13 +303,17 @@ GnomeFontFace *GPOFontMap::getFontFaceEmbedded(GfxFont *font)
   case fontCIDType0C: {
     FoFiType1C *ff;
     gint n_cids;
+#if HAVE_FREETYPE_217_OR_OLDER
     gushort *code_to_gid;
+#endif
     
     ff = FoFiType1C::make((char *)contents, length);
     if (!ff)
       return getFontFaceFallback(font);
 
+#if HAVE_FREETYPE_217_OR_OLDER
     code_to_gid = ff->getCIDToGIDMap(&n_cids); // this is g(oo)malloc'd
+#endif
     delete ff;
 
     gff = gpdf_font_face_download((const guchar *)font_name,
@@ -317,10 +321,13 @@ GnomeFontFace *GPOFontMap::getFontFaceEmbedded(GfxFont *font)
 				  GNOME_FONT_REGULAR, FALSE,
 				  contents, length);
 
+#if HAVE_FREETYPE_217_OR_OLDER
+    /* freetype >= 2.1.8 can handle Type1C fonts fine without this */
     g_object_set_data((GObject *)gff, "code-to-gid-len",
 		      GINT_TO_POINTER(n_cids));
     g_object_set_data_full((GObject *)gff, "code-to-gid", code_to_gid,
 			   (GDestroyNotify)gfree);
+#endif
     break;
   }
   case fontCIDType2: {
